Context

Struct Context 

pub struct Context {
    pub method: String,
    pub path: String,
    pub params: HashMap<String, String>,
    pub headers: HashMap<String, String>,
    pub query: HashMap<String, String>,
    pub body: Value,
    pub user_id: Option<String>,
    pub is_admin: bool,
    pub request_id: Option<String>,
}
Context passed to plugin handlers.

Contains all information about the incoming request.

Fields

method: String

HTTP method (GET, POST, etc.)

path: String

Request path

params: HashMap<String, String>

Path parameters (extracted from route pattern)

headers: HashMap<String, String>

Request headers

query: HashMap<String, String>

Query string parameters

body: Value

Request body (parsed as JSON)

user_id: Option<String>

Authenticated user ID (if any)

is_admin: bool

Whether the user is an admin

request_id: Option<String>

Request ID for tracing

Implementations

Source

impl Context

pub fn from_raw(_ptr: i32, _len: i32) -> Result<Self>

Parse context from raw FFI pointer (non-WASM stub)

pub fn param(&self, name: &str) -> Option<&str>

Get a path parameter by name

pub fn param_required(&self, name: &str) -> Result<&str>

Get a required path parameter, or return an error

pub fn query_param(&self, name: &str) -> Option<&str>

Get a query parameter by name

pub fn query_param_or<'a>(&'a self, name: &str, default: &'a str) -> &'a str

Get a query parameter with a default value

pub fn query_param_as<T: FromStr>(&self, name: &str) -> Option<T>

Get a query parameter parsed as a specific type

pub fn header(&self, name: &str) -> Option<&str>

Get a header by name (case-insensitive)

pub fn body_as<T: for<'de> Deserialize<'de>>(&self) -> Result<T>

Parse the request body as a specific type

pub fn body_field(&self, name: &str) -> Option<&Value>

Get a field from the body

pub fn body_field_as<T: for<'de> Deserialize<'de>>( &self, name: &str, ) -> Result<Option<T>>

Get a field from the body as a specific type

pub const fn is_authenticated(&self) -> bool

Check if the request is authenticated

pub fn require_auth(&self) -> Result<&str>

Require authentication, return error if not authenticated

pub fn require_admin(&self) -> Result<()>

Require admin access

pub fn is_method(&self, method: &str) -> bool

Check if the request method matches

pub fn pagination(&self) -> (u32, u32)

Get pagination parameters from query string

Returns (page, per_page) with defaults of (1, 20)

pub fn pagination_offset(&self) -> (u32, u32)

Get offset/limit for database queries from pagination

Returns (offset, limit)