pub trait ToDbParams {
// Required method
fn to_db_params(&self) -> Vec<DbValue>;
}Expand description
Trait for types that can be converted to database parameters
pub trait ToDbParams {
// Required method
fn to_db_params(&self) -> Vec<DbValue>;
}Trait for types that can be converted to database parameters