Enhanced UI component and page definitions for JSON-described GUI.
This module provides comprehensive types for defining dynamic UIs from JSON schemas, supporting state management, event handling, and complex component compositions.
Structs
- Accordion
Item - Accordion item.
- ArgMapping
- Argument mapping for API calls.
- Breadcrumb
Item - Breadcrumb item.
- Component
Schema - Enhanced component schema for JSON-described UI.
- Custom
Validation - Custom validation rule.
- Dialog
Definition - Dialog definition for modals.
- Event
Handlers - Event handlers that can be attached to components.
- Form
Field - Form field definition.
- Navigation
Config - Navigation configuration.
- Navigation
Item - Navigation menu item.
- Page
Definition - Enhanced page definition for plugin UI.
- Page
Lifecycle Hooks - Page lifecycle hooks.
- Select
Option - Select option.
- State
Field Definition - A single state field definition.
- TabItem
- Tab item.
- Table
Column - Table column definition.
- Validation
Rule - Validation rule.
Enums
- Action
- Action that can be executed in response to events.
- State
Field Type - State field type enumeration.
- Toast
Level - Toast notification level.